Module btree_map

Module btree_map 

Provides TotalBTreeMap, an ordered map in which every possible key has an associated value. Only entries with uncommon values are actually stored in the map; all other keys are presumed to be associated with a common value.

Structs

AsBTreeMapMut
A mutable view into the underlying BTreeMap of a TotalBTreeMap.
Entry
A view into a single entry in a TotalBTreeMap.
IntoIter
An owning iterator over the uncommon entries in a TotalBTreeMap.
IntoKeys
An owning iterator over the keys associated with uncommon values in a TotalBTreeMap.
IntoValues
An owning iterator over the uncommon values in a TotalBTreeMap.
Iter
An iterator over the uncommon entries in a TotalBTreeMap.
Keys
An iterator over the keys associated with uncommon values in a TotalBTreeMap.
TotalBTreeMap
An ordered map in which every possible key has an associated value. Only entries with uncommon values are actually stored in the map; all other keys are presumed to be associated with a common value.
Values
An iterator over the uncommon values in a TotalBTreeMap.