Module empty

Module empty 

Provides EmptyCommonality, a commonality for collection types where the common value is an empty collection.

Structs

EmptyCommonality
A commonality for collection types, where the common value is an empty collection.