Module nonzero

Module nonzero 

Maps that only store entries with nonzero values.

These types are recommended whenever it is important that the common value is zero, even though most numeric types’ Default implementations also yield a zero value.

Structs

ZeroCommonality
A commonality based on the Zero trait.

Type Aliases

NonZeroBTreeMap
An ordered map that only stores entries with non-zero values. All other keys are presumed to be associated with the zero value.
NonZeroHashMap
A hash map that only stores entries with non-zero values. All other keys are presumed to be associated with the zero value.