Provides TotalBTreeMap, an ordered map in which every possible key has an associated value. Only entries with uncommon values are actually stored in the map; all other keys are presumed to be associated with a common value.
Structs
- AsBTree
MapMut - A mutable view into the underlying BTreeMap of a TotalBTreeMap.
- Entry
- A view into a single entry in a TotalBTreeMap.
- Into
Iter - An owning iterator over the uncommon entries in a TotalBTreeMap.
- Into
Keys - An owning iterator over the keys associated with uncommon values in a TotalBTreeMap.
- Into
Values - An owning iterator over the uncommon values in a TotalBTreeMap.
- Iter
- An iterator over the uncommon entries in a TotalBTreeMap.
- Keys
- An iterator over the keys associated with uncommon values in a TotalBTreeMap.
- TotalB
Tree Map - An ordered map in which every possible key has an associated value. Only entries with uncommon values are actually stored in the map; all other keys are presumed to be associated with a common value.
- Values
- An iterator over the uncommon values in a TotalBTreeMap.