Module total_maps::btree_map

source ·
Provides TotalBTreeMap, an ordered map in which every possible key has an associated value. Only entries with uncommon values are actually stored in the map; all other keys are presumed to be associated with a common value.

Structs