Module total_maps::btree_map
source · Expand description
Provides TotalBTreeMap, an ordered map in which every possible key has an associated value. Only entries with uncommon values are actually stored in the map; all other keys are presumed to be associated with a common value.
Structs
- A mutable view into the underlying BTreeMap of a TotalBTreeMap.
- A view into a single entry in a TotalBTreeMap.
- An owning iterator over the uncommon entries in a TotalBTreeMap.
- An owning iterator over the keys associated with uncommon values in a TotalBTreeMap.
- An owning iterator over the uncommon values in a TotalBTreeMap.
- An iterator over the uncommon entries in a TotalBTreeMap.
- An iterator over the keys associated with uncommon values in a TotalBTreeMap.
- An ordered map in which every possible key has an associated value. Only entries with uncommon values are actually stored in the map; all other keys are presumed to be associated with a common value.
- An iterator over the uncommon values in a TotalBTreeMap.