Provides EmptyCommonality, a commonality for collection types where the common value is an empty collection.
Structs
- Empty
Commonality - A commonality for collection types, where the common value is an empty collection.
Provides EmptyCommonality, a commonality for collection types where the common value is an empty collection.