Module total_maps::empty
source · Expand description
Provides EmptyCommonality, a commonality for collection types where the common value is an empty collection.
Structs
- A commonality for collection types, where the common value is an empty collection.