Provides TotalHashMap, a hash map in which every possible key has an associated value. Only entries with uncommon values are actually stored in the map; all other keys are presumed to be associated with a common value.
Structs
- AsHash
MapMut - A mutable view into the underlying HashMap of a TotalHashMap.
- Drain
- A draining iterator over the uncommon entries in a TotalHashMap.
- Entry
- A view into a single entry in a TotalHashMap.
- Into
Iter - An owning iterator over the uncommon entries in a TotalHashMap.
- Into
Keys - An owning iterator over the keys associated with uncommon values in a TotalHashMap.
- Into
Values - An owning iterator over the uncommon values in a TotalHashMap.
- Iter
- An iterator over the uncommon entries in a TotalHashMap.
- Keys
- An iterator over the keys associated with uncommon values in a TotalHashMap.
- Total
Hash Map - A hash map in which every possible key has an associated value. Only entries with uncommon values are actually stored in the map; all other keys are presumed to be associated with a common value.
- Values
- An iterator over the uncommon values in a TotalHashMap.