pub type NonZeroBTreeMap<K, V> = TotalBTreeMap<K, V, ZeroCommonality>;Expand description
An ordered map that only stores entries with non-zero values. All other keys are presumed to be associated with the zero value.
Aliased Type
pub struct NonZeroBTreeMap<K, V> { /* private fields */ }