Type Alias total_maps::nonzero::NonZeroBTreeMap

source ·
pub type NonZeroBTreeMap<K, V> = TotalBTreeMap<K, V, ZeroCommonality>;
An ordered map that only stores entries with non-zero values. All other keys are presumed to be associated with the zero value.

Aliased Type

struct NonZeroBTreeMap<K, V> { /* private fields */ }