pub type NonZeroHashMap<K, V> = TotalHashMap<K, V, ZeroCommonality>;Expand description
A hash map that only stores entries with non-zero values. All other keys are presumed to be associated with the zero value.
Aliased Type
pub struct NonZeroHashMap<K, V> { /* private fields */ }