Type Alias total_maps::nonzero::NonZeroHashMap

source ·
pub type NonZeroHashMap<K, V> = TotalHashMap<K, V, ZeroCommonality>;
A hash map that only stores entries with non-zero values. All other keys are presumed to be associated with the zero value.

Aliased Type

struct NonZeroHashMap<K, V> { /* private fields */ }